Module output

Module output 

Output glue. The single seam through which CLI subcommands write their one line of JSON to stdout.

Functions

emit
Emit a payload to stdout as one line of JSON. Wraps shared::afdata::emit and is the single seam through which CLI subcommands produce output.
emit_progress
Emit one non-terminal progress event. Only commands that block on a person have anything to report before their result.
emit_revealing_takeover
Emit an otherwise-redacted result while revealing only the short-lived takeover capability requested by an explicit panel/takeover operation.
emit_unredacted
Emit a payload to stdout without AFDATA redaction. This is only for explicit reveal flags; normal command output must use emit.