pub struct TakeoverSupport {
pub backend_capable: bool,
pub supported: bool,
pub panel_url: Option<String>,
pub provider: Option<String>,
}Expand description
Human-takeover panel support. provider names the concrete screen-share
method (kasmvnc, …) — open-ended like BackendFamily.family, so adding a
provider does not change this shape.
Fields
backend_capable: boolWhether this backend can expose a takeover panel at all when the host is
started with --takeover-provider <provider> (false for lightpanda).
supported: boolWhether this host actually has a takeover panel enabled right now.
panel_url: Option<String>provider: Option<String>Trait Implementations
Sourceimpl Clone for TakeoverSupport
impl Clone for TakeoverSupport
Sourcefn clone(&self) -> TakeoverSupport
fn clone(&self) -> TakeoverSupport
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TakeoverSupport
impl Debug for TakeoverSupport
Sourceimpl<'de> Deserialize<'de> for TakeoverSupport
impl<'de> Deserialize<'de> for TakeoverSupport
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more