pub struct NextAction {
pub kind: NextActionKind,
pub recommended_command: String,
pub target_content_verified: bool,
pub takeover_url: Option<String>,
pub takeover_url_expires_at_rfc3339: Option<String>,
pub takeover_url_ttl_s: Option<u64>,
pub takeover_url_scope: Option<String>,
}Fields
kind: NextActionKindrecommended_command: Stringtarget_content_verified: booltakeover_url: Option<String>Real-display takeover URL a human opens to clear the wall. Populated by
afhttp fetch --takeover once it has prepared a persistent tab on a
takeover-ready host; None for a bare fetch that only detected the wall.
takeover_url_expires_at_rfc3339: Option<String>takeover_url_ttl_s: Option<u64>takeover_url_scope: Option<String>Trait Implementations
Sourceimpl Clone for NextAction
impl Clone for NextAction
Sourcefn clone(&self) -> NextAction
fn clone(&self) -> NextAction
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for NextAction
impl Debug for NextAction
Sourceimpl<'de> Deserialize<'de> for NextAction
impl<'de> Deserialize<'de> for NextAction
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for NextAction
Sourceimpl PartialEq for NextAction
impl PartialEq for NextAction
Sourcefn eq(&self, other: &NextAction) -> bool
fn eq(&self, other: &NextAction) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for NextAction
impl Serialize for NextAction
impl StructuralPartialEq for NextAction