pub fn emit_unredacted<W: Write, T: Serialize>(
writer: &mut W,
code: &str,
payload: &T,
) -> Result<(), Error>Expand description
Emit a payload without AFDATA redaction. Use only for commands that require an explicit reveal flag and whose payload contains no unrelated secrets.