Module skill

Module skill 

afhttp skill subcommand. Installs/uninstalls/reports status of the embedded Agent Skill across Codex, Claude Code, and opencode via the shared agent_first_data::skill admin.

Structs

Args
TargetArgs
WriteArgs

Enums

SkillSub

Functions

run