afhttp skill subcommand. Installs/uninstalls/reports status of the embedded Agent Skill across Codex, Claude Code, and opencode via the shared agent_first_data::skill admin.
afhttp skill
agent_first_data::skill